Python bindings to the OpenStack Watcher API
============================================

This is a client for OpenStack Watcher API. There's a Python API
(the :mod:`watcherclient` modules), and a command-line script
(installed as :program:`watcher`). Each implements the entire
OpenStack Watcher API.

.. toctree::
   :maxdepth: 2

   cli/index
   reference/index
   installation
   contributing
